package com.magnatune.eyecreate.companionformagnatune;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.support.v4.app.FragmentTransaction;
import android.support.v4.content.ContextCompat;
import android.support.v4.content.LocalBroadcastManager;

import com.heinrichreimersoftware.materialdrawer.DrawerActivity;
import com.heinrichreimersoftware.materialdrawer.structure.DrawerItem;
import com.heinrichreimersoftware.materialdrawer.structure.DrawerProfile;
import com.magnatune.eyecreate.companionformagnatune.fragments.AlbumsFragment;
import com.magnatune.eyecreate.companionformagnatune.fragments.ArtistFragment;
import com.magnatune.eyecreate.companionformagnatune.fragments.ArtistsFragment;
import com.magnatune.eyecreate.companionformagnatune.login.MagnatuneAccountManager;

public class BrowseActivity extends DrawerActivity {

    public static final String ACTION_ONCLICK_ACTIVATED = "browseactivityonclick";
    public static final String EXTRA_FRAGMENT = "fragmenttostart";
    public static final String EXTRA_FRAGMENT_ARGS = "fragmentargs";

    BroadcastReceiver onClickManager = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            if(intent.hasExtra(EXTRA_FRAGMENT)) {
                if(intent.getStringExtra(EXTRA_FRAGMENT).equals(ArtistFragment.class.getName())) {
                    ArtistFragment fragment = new ArtistFragment();
                    fragment.setArguments(intent.getBundleExtra(EXTRA_FRAGMENT_ARGS));
                    getSupportFragmentManager().beginTransaction()
                            .setCustomAnimations(R.anim.fragment_enter,R.anim.fragment_exit,R.anim.fragment_pop_enter,R.anim.fragment_pop_exit)
                            .replace(R.id.fragment_holder,fragment,"artist")
                            .addToBackStack("artist")
                            .commit();
                }
            }
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_browse);
        addProfile(new DrawerProfile()
                .setName(MagnatuneAccountManager.getMagnatuneName())
                .setDescription(MagnatuneAccountManager.isLoggedIn() ? getString(R.string.click_to_logout) : getString(R.string.click_to_login))
                .setRoundedAvatar((BitmapDrawable) ContextCompat.getDrawable(this, R.drawable.ic_account_white_48dp))
                .setBackground(new ColorDrawable(ContextCompat.getColor(this, R.color.primary))));

        addItem(new DrawerItem()
                .setTextPrimary(getString(R.string.albums))
                .setOnItemClickListener(new DrawerItem.OnItemClickListener() {
                    @Override
                    public void onClick(DrawerItem drawerItem, long l, int i) {
                        getSupportFragmentManager().beginTransaction()
                                .setCustomAnimations(R.anim.fragment_enter, R.anim.fragment_exit)
                                .replace(R.id.fragment_holder, new AlbumsFragment(), "albums")
                                .commit();
                        closeDrawer();
                    }
                }));
        addItem(new DrawerItem()
                .setTextPrimary(getString(R.string.artists))
                .setOnItemClickListener(new DrawerItem.OnItemClickListener() {
                    @Override
                    public void onClick(DrawerItem drawerItem, long l, int i) {
                        getSupportFragmentManager().beginTransaction()
                                .setCustomAnimations(R.anim.fragment_enter, R.anim.fragment_exit)
                                .replace(R.id.fragment_holder, new ArtistsFragment(), "artists")
                                .setTransition(FragmentTransaction.TRANSIT_FRAGMENT_OPEN)
                                .commit();
                        closeDrawer();
                    }
                }));

        if(savedInstanceState == null) {
            getSupportFragmentManager().beginTransaction()
                    .replace(R.id.fragment_holder,new AlbumsFragment(),"albums")
                    .commit();
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        LocalBroadcastManager.getInstance(this).registerReceiver(onClickManager,new IntentFilter(ACTION_ONCLICK_ACTIVATED));
    }

    @Override
    protected void onPause() {
        super.onPause();
        LocalBroadcastManager.getInstance(this).unregisterReceiver(onClickManager);
    }
}
